=====
Tengu
=====


.. image:: https://img.shields.io/pypi/v/tengu.svg
        :target: https://pypi.python.org/pypi/tengu

.. image:: https://img.shields.io/travis/andecy64/tengu.svg
        :target: https://travis-ci.org/andecy64/tengu

.. image:: https://readthedocs.org/projects/tengu/badge/?version=latest
        :target: https://tengu.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Tengu is an OpenBalkans node implementation


* Free software: MIT license
* Documentation: https://tengu.readthedocs.io.


Features
--------

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
